@@ -282,6 +282,36 @@ void MainMenu::on_actionRun_LaTeX_triggered()
     tikzit->makePreview();
 }
 
+void MainMenu::on_actionPrevious_Node_Style_triggered()
+{
+    tikzit->activeWindow()->stylePalette()->previousNodeStyle();
+}
+
+void MainMenu::on_actionNext_Node_Style_triggered()
+{
+    tikzit->activeWindow()->stylePalette()->nextNodeStyle();
+}
+
+void MainMenu::on_actionClear_Node_Style_triggered()
+{
+    tikzit->activeWindow()->stylePalette()->toggleClearNodeStyle();
+}
+
+void MainMenu::on_actionPrevious_Edge_Style_triggered()
+{
+    tikzit->activeWindow()->stylePalette()->previousEdgeStyle();
+}
+
+void MainMenu::on_actionNext_Edge_Style_triggered()
+{
+    tikzit->activeWindow()->stylePalette()->nextEdgeStyle();
+}
+
+void MainMenu::on_actionClear_Edge_Style_triggered()
+{
+    tikzit->activeWindow()->stylePalette()->toggleClearEdgeStyle();
+}
+
 void MainMenu::on_actionPreferences_triggered()
 {
     PreferenceDialog *d = new PreferenceDialog(this);
@@ -301,6 +331,12 @@ void MainMenu::on_actionZoom_Out_triggered()
     if (tikzit->activeWindow() != 0) tikzit->activeWindow()->tikzView()->zoomOut();
 }
 
+void MainMenu::on_actionShow_Node_Labels_triggered()
+{
+    tikzit->activeWindow()->tikzScene()->setDrawNodeLabels(ui.actionShow_Node_Labels->isChecked());
+    tikzit->activeWindow()->tikzScene()->invalidate();
+}
+
 void MainMenu::on_actionAbout_triggered()
 {
     QMessageBox::about(this,
