@@ -38,6 +38,7 @@ TikzScene::TikzScene(TikzDocument *tikzDocument, ToolPalette *tools,
 {
     _modifyEdgeItem = nullptr;
     _edgeStartNodeItem = nullptr;
+    _drawNodeLabels = true;
     _drawEdgeItem = new QGraphicsLineItem();
     _rubberBandItem = new QGraphicsRectItem();
     _enabled = true;
@@ -707,25 +708,6 @@ void TikzScene::keyReleaseEvent(QKeyEvent *event)
     }
 
 
-    if (event->key() == Qt::Key_Backspace || event->key() == Qt::Key_Delete) {
-        deleteSelectedItems();
-    } else if (mod == Qt::NoModifier) {
-        switch(event->key()) {
-        case Qt::Key_S:
-            tikzit->activeWindow()->toolPalette()->setCurrentTool(ToolPalette::SELECT);
-            break;
-        case Qt::Key_V:
-        case Qt::Key_N:
-            tikzit->activeWindow()->toolPalette()->setCurrentTool(ToolPalette::VERTEX);
-            break;
-        case Qt::Key_E:
-            tikzit->activeWindow()->toolPalette()->setCurrentTool(ToolPalette::EDGE);
-            break;
-        case Qt::Key_B:
-            tikzit->activeWindow()->toolPalette()->setCurrentTool(ToolPalette::CROP);
-            break;
-        }
-    }
 
     foreach (QGraphicsItem *it, selectedItems()) it->update();
 }
@@ -739,11 +721,6 @@ void TikzScene::keyPressEvent(QKeyEvent *event)
     // slower, but seems to be more reliable than event->modifiers()
     Qt::KeyboardModifiers mod = QApplication::queryKeyboardModifiers();
 
-    if (event->key() == Qt::Key_QuoteLeft) {
-        capture = true;
-        _styles->nextNodeStyle();
-    }
-
     if (mod & Qt::ControlModifier) {
         QSet<Node*> selNodes;
         QSet<Edge*> selEdges;
@@ -865,6 +842,26 @@ void TikzScene::keyPressEvent(QKeyEvent *event)
                 _tikzDocument->undoStack()->endMacro();
             }
         }
+    } else { // no CTRL key
+        if (event->key() == Qt::Key_Backspace || event->key() == Qt::Key_Delete) {
+            deleteSelectedItems();
+        } else if (!event->isAutoRepeat()) {
+            switch(event->key()) {
+            case Qt::Key_S:
+                tikzit->activeWindow()->toolPalette()->setCurrentTool(ToolPalette::SELECT);
+                break;
+            case Qt::Key_V:
+            case Qt::Key_N:
+                tikzit->activeWindow()->toolPalette()->setCurrentTool(ToolPalette::VERTEX);
+                break;
+            case Qt::Key_E:
+                tikzit->activeWindow()->toolPalette()->setCurrentTool(ToolPalette::EDGE);
+                break;
+            case Qt::Key_B:
+                tikzit->activeWindow()->toolPalette()->setCurrentTool(ToolPalette::CROP);
+                break;
+            }
+        }
     }
 
     foreach (QGraphicsItem *it, selectedItems()) it->update();
@@ -907,6 +904,16 @@ void TikzScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
     }
 }
 
+bool TikzScene::drawNodeLabels() const
+{
+    return _drawNodeLabels;
+}
+
+void TikzScene::setDrawNodeLabels(bool drawNodeLabels)
+{
+    _drawNodeLabels = drawNodeLabels;
+}
+
 bool TikzScene::highlightTails() const
 {
     return _highlightTails && getSelectedNodes().isEmpty();
